{% load static %}
<meta charset="utf-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="description" content="">
<meta name="author" content="">

<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
<link href="https://fonts.googleapis.com/css2?family=Montserrat:wght@500;600;700&family=Open+Sans&display=swap"
	  rel="stylesheet">

<link href="{% static 'basic/assets/css/bootstrap.min.css' %}" rel="stylesheet">
<link href="{% static 'basic/assets/css/bootstrap-icons.css' %}" rel="stylesheet">
<link href="{% static 'basic/assets/css/templatemo-topic-listing.css' %}" rel="stylesheet">